Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/acorn26 u_int*_t -> uint*_t



details:   https://anonhg.NetBSD.org/src/rev/f04d18965a79
branches:  trunk
changeset: 779218:f04d18965a79
user:      skrll <skrll%NetBSD.org@localhost>
date:      Fri May 11 15:39:17 2012 +0000

description:
u_int*_t -> uint*_t

Same code before and after.

diffstat:

 sys/arch/acorn26/acorn26/except.c        |   8 ++--
 sys/arch/acorn26/acorn26/irq.c           |  12 ++++----
 sys/arch/acorn26/acorn26/machdep.c       |  10 +++---
 sys/arch/acorn26/acorn26/pmap.c          |  14 ++++----
 sys/arch/acorn26/include/boot.h          |  44 +++++++++++++++---------------
 sys/arch/acorn26/include/memcreg.h       |   4 +-
 sys/arch/acorn26/iobus/ioc.c             |  10 +++---
 sys/arch/acorn26/iobus/iocvar.h          |  10 +++---
 sys/arch/acorn26/ioc/if_eca.c            |   6 ++--
 sys/arch/acorn26/ioc/if_ecavar.h         |  16 +++++-----
 sys/arch/acorn26/ioc/latches.c           |  12 ++++----
 sys/arch/acorn26/ioc/latchvar.h          |   6 ++--
 sys/arch/acorn26/ioc/ssn.c               |  12 ++++----
 sys/arch/acorn26/podulebus/if_eh.c       |  46 ++++++++++++++++----------------
 sys/arch/acorn26/podulebus/podulebus.c   |  20 ++++++------
 sys/arch/acorn26/stand/lib/riscoscalls.h |  42 ++++++++++++++--------------
 sys/arch/acorn26/vidc/arcvideo.c         |  14 ++++----
 sys/arch/acorn26/vidc/vidcreg.h          |   4 +-
 18 files changed, 145 insertions(+), 145 deletions(-)

diffs (truncated from 888 to 300 lines):

diff -r 9c21a4e67f10 -r f04d18965a79 sys/arch/acorn26/acorn26/except.c
--- a/sys/arch/acorn26/acorn26/except.c Fri May 11 14:51:39 2012 +0000
+++ b/sys/arch/acorn26/acorn26/except.c Fri May 11 15:39:17 2012 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: except.c,v 1.27 2010/12/20 00:25:23 matt Exp $ */
+/* $NetBSD: except.c,v 1.28 2012/05/11 15:39:17 skrll Exp $ */
 /*-
  * Copyright (c) 1998, 1999, 2000 Ben Harris
  * All rights reserved.
@@ -31,7 +31,7 @@
 
 #include <sys/param.h>
 
-__KERNEL_RCSID(0, "$NetBSD: except.c,v 1.27 2010/12/20 00:25:23 matt Exp $");
+__KERNEL_RCSID(0, "$NetBSD: except.c,v 1.28 2012/05/11 15:39:17 skrll Exp $");
 
 #include "opt_ddb.h"
 
@@ -81,10 +81,10 @@
 void
 checkvectors(void)
 {
-       u_int32_t *ptr;
+       uint32_t *ptr;
 
        /* Check that the vectors are valid */
-       for (ptr = (u_int32_t *)0; ptr < (u_int32_t *)0x1c; ptr++)
+       for (ptr = (uint32_t *)0; ptr < (uint32_t *)0x1c; ptr++)
                if (*ptr != 0xe59ff114)
                        panic("CPU vectors mangled");
 }
diff -r 9c21a4e67f10 -r f04d18965a79 sys/arch/acorn26/acorn26/irq.c
--- a/sys/arch/acorn26/acorn26/irq.c    Fri May 11 14:51:39 2012 +0000
+++ b/sys/arch/acorn26/acorn26/irq.c    Fri May 11 15:39:17 2012 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: irq.c,v 1.16 2010/12/20 00:25:23 matt Exp $ */
+/* $NetBSD: irq.c,v 1.17 2012/05/11 15:39:17 skrll Exp $ */
 
 /*-
  * Copyright (c) 2000, 2001 Ben Harris
@@ -31,7 +31,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: irq.c,v 1.16 2010/12/20 00:25:23 matt Exp $");
+__KERNEL_RCSID(0, "$NetBSD: irq.c,v 1.17 2012/05/11 15:39:17 skrll Exp $");
 
 #include <sys/param.h>
 #include <sys/device.h>
@@ -87,7 +87,7 @@
  * be represented eventually.
  */
 
-static u_int32_t irqmask[NIPL];
+static uint32_t irqmask[NIPL];
 
 LIST_HEAD(irq_handler_head, irq_handler) irq_list_head =
     LIST_HEAD_INITIALIZER(irq_list_head);
@@ -96,7 +96,7 @@
        LIST_ENTRY(irq_handler) link;
        int     (*func)(void *);
        void    *arg;
-       u_int32_t       mask;
+       uint32_t        mask;
        int     irqnum;
        int     ipl;
        int     enabled;
@@ -355,7 +355,7 @@
 hardsplx(int s)
 {
        int was;
-       u_int32_t mask;
+       uint32_t mask;
 
        KASSERT(s < IPL_HIGH);
        int_off();
@@ -426,7 +426,7 @@
 {
        struct irq_handler *h;
        int i;
-       u_int32_t last;
+       uint32_t last;
 
        for (h = irq_list_head.lh_first; h != NULL; h = h->link.le_next)
                (*pr)("%12s: ipl %2d, IRQ %2d, mask 0x%05x, count %llu\n",
diff -r 9c21a4e67f10 -r f04d18965a79 sys/arch/acorn26/acorn26/pmap.c
--- a/sys/arch/acorn26/acorn26/pmap.c   Fri May 11 14:51:39 2012 +0000
+++ b/sys/arch/acorn26/acorn26/pmap.c   Fri May 11 15:39:17 2012 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: pmap.c,v 1.35 2012/02/12 16:34:06 matt Exp $ */
+/* $NetBSD: pmap.c,v 1.36 2012/05/11 15:39:17 skrll Exp $ */
 /*-
  * Copyright (c) 1997, 1998, 2000 Ben Harris
  * All rights reserved.
@@ -102,7 +102,7 @@
 
 #include <sys/param.h>
 
-__KERNEL_RCSID(0, "$NetBSD: pmap.c,v 1.35 2012/02/12 16:34:06 matt Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pmap.c,v 1.36 2012/05/11 15:39:17 skrll Exp $");
 
 #include <sys/kernel.h> /* for cold */
 #include <sys/kmem.h>
@@ -136,15 +136,15 @@
        pmap_t  pv_pmap;
        int     pv_ppn;
        int     pv_lpn;
-       u_int32_t       pv_activate;  /* MEMC command to activate mapping */
-       u_int32_t       pv_deactivate;/* MEMC command to deactivate mapping */
+       uint32_t        pv_activate;  /* MEMC command to activate mapping */
+       uint32_t        pv_deactivate;/* MEMC command to deactivate mapping */
        vm_prot_t       pv_prot; /* requested protection */
-       u_int8_t        pv_ppl;  /* Actual PPL */
-       u_int8_t        pv_vflags; /* Per-mapping flags */
+       uint8_t pv_ppl;  /* Actual PPL */
+       uint8_t pv_vflags; /* Per-mapping flags */
 #define PV_WIRED       0x01 /* This is a wired mapping */
 #define PV_UNMANAGED   0x02 /* Mapping was entered by pmap_kenter_*() */
        /* From pv_pflags onwards is per-physical-page state. */
-       u_int8_t        pv_pflags; /* Per-physical-page flags */
+       uint8_t pv_pflags; /* Per-physical-page flags */
 #define PV_REFERENCED  0x01
 #define PV_MODIFIED    0x02
 #ifdef PMAP_DEBUG_MODIFIED
diff -r 9c21a4e67f10 -r f04d18965a79 sys/arch/acorn26/include/boot.h
--- a/sys/arch/acorn26/include/boot.h   Fri May 11 14:51:39 2012 +0000
+++ b/sys/arch/acorn26/include/boot.h   Fri May 11 15:39:17 2012 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: boot.h,v 1.3 2009/01/14 23:14:48 bjh21 Exp $ */
+/* $NetBSD: boot.h,v 1.4 2012/05/11 15:39:17 skrll Exp $ */
 /*-
  * Copyright (c) 1998 Ben Harris
  * All rights reserved.
@@ -50,31 +50,31 @@
 #define BOOT_MAGIC 0x942B7DFE
 
 struct bootconfig {
-       u_int32_t magic;        /* BOOT_MAGIC */
-       u_int32_t version;      /* minor version of structure */
+       uint32_t magic;         /* BOOT_MAGIC */
+       uint32_t version;       /* minor version of structure */
        /* Standard NetBSD boot parameters */
-       u_int32_t boothowto;    /* Reboot flags (single-user etc) */
-       u_int32_t bootdev;      /* Boot device */
-       u_int32_t ssym;         /* Start of debugging symbols */
-       u_int32_t esym;         /* End of debugging symbols */
+       uint32_t boothowto;     /* Reboot flags (single-user etc) */
+       uint32_t bootdev;       /* Boot device */
+       uint32_t ssym;          /* Start of debugging symbols */
+       uint32_t esym;          /* End of debugging symbols */
        /* Parameters gathered by OS_ReadMemMapInfo */
-       u_int32_t nbpp;         /* Machine page size in bytes */
-       u_int32_t npages;       /* Number of pages */
+       uint32_t nbpp;          /* Machine page size in bytes */
+       uint32_t npages;        /* Number of pages */
        /* Layout of physical memory. */
-       u_int32_t txtbase;      /* Kernel text base */
-       u_int32_t txtsize;      /* ... and size */
-       u_int32_t database;     /* Ditto for data */
-       u_int32_t datasize;     /* and bss */
-       u_int32_t bssbase;      /* Note that base addresses are */
-       u_int32_t bsssize;      /* "physical" ie bytes above 0x02000000 */
-       u_int32_t freebase;     /* Start of free space */
+       uint32_t txtbase;       /* Kernel text base */
+       uint32_t txtsize;       /* ... and size */
+       uint32_t database;      /* Ditto for data */
+       uint32_t datasize;      /* and bss */
+       uint32_t bssbase;       /* Note that base addresses are */
+       uint32_t bsssize;       /* "physical" ie bytes above 0x02000000 */
+       uint32_t freebase;      /* Start of free space */
        /* Framebuffer state -- used to initialise raster console */
-       u_int32_t xpixels;      /* Pixels across screen (XWindLimit + 1) */
-       u_int32_t ypixels;      /* Pixels down screen (YWindLimit + 1) */
-       u_int32_t bpp;          /* Bits per pixel (1 << Log2BPP) */
-       u_int32_t screenbase;   /* Physical base of screen */
-       u_int32_t screensize;   /* Size of framebuffer (TotalScreenSize) */
-       u_int32_t cpixelrow;    /* first free pixel row on screen */
+       uint32_t xpixels;       /* Pixels across screen (XWindLimit + 1) */
+       uint32_t ypixels;       /* Pixels down screen (YWindLimit + 1) */
+       uint32_t bpp;           /* Bits per pixel (1 << Log2BPP) */
+       uint32_t screenbase;    /* Physical base of screen */
+       uint32_t screensize;    /* Size of framebuffer (TotalScreenSize) */
+       uint32_t cpixelrow;     /* first free pixel row on screen */
        /* Version 0 ends here */
 };
 
diff -r 9c21a4e67f10 -r f04d18965a79 sys/arch/acorn26/include/memcreg.h
--- a/sys/arch/acorn26/include/memcreg.h        Fri May 11 14:51:39 2012 +0000
+++ b/sys/arch/acorn26/include/memcreg.h        Fri May 11 15:39:17 2012 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: memcreg.h,v 1.3 2007/03/04 05:59:04 christos Exp $ */
+/* $NetBSD: memcreg.h,v 1.4 2012/05/11 15:39:17 skrll Exp $ */
 /*-
  * Copyright (c) 1997, 1998 Ben Harris
  * All rights reserved.
@@ -40,7 +40,7 @@
  * new value, and write any word to the resultant address.
  */
 
-#define MEMC_WRITE(value) *(volatile u_int32_t *)value = 0
+#define MEMC_WRITE(value) *(volatile uint32_t *)value = 0
 
 /*
  * This information is mostly derived from:
diff -r 9c21a4e67f10 -r f04d18965a79 sys/arch/acorn26/iobus/ioc.c
--- a/sys/arch/acorn26/iobus/ioc.c      Fri May 11 14:51:39 2012 +0000
+++ b/sys/arch/acorn26/iobus/ioc.c      Fri May 11 15:39:17 2012 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: ioc.c,v 1.20 2011/07/19 16:05:10 dyoung Exp $ */
+/* $NetBSD: ioc.c,v 1.21 2012/05/11 15:39:17 skrll Exp $ */
 
 /*-
  * Copyright (c) 1998, 1999, 2000 Ben Harris
@@ -31,7 +31,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ioc.c,v 1.20 2011/07/19 16:05:10 dyoung Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ioc.c,v 1.21 2012/05/11 15:39:17 skrll Exp $");
 
 #include <sys/param.h>
 #include <sys/device.h>
@@ -191,7 +191,7 @@
                        IOC_IRQB_BIT(irq)) != 0;
 }
 
-u_int32_t
+uint32_t
 ioc_irq_status_full(void)
 {
        struct ioc_softc *sc = device_private(the_ioc);
@@ -208,7 +208,7 @@
 }
 
 void
-ioc_irq_setmask(u_int32_t mask)
+ioc_irq_setmask(uint32_t mask)
 {
        struct ioc_softc *sc = device_private(the_ioc);
        bus_space_tag_t bst = sc->sc_bst;
@@ -268,7 +268,7 @@
  */
 
 void
-ioc_fiq_setmask(u_int32_t mask)
+ioc_fiq_setmask(uint32_t mask)
 {
        struct ioc_softc *sc = device_private(the_ioc);
        bus_space_tag_t bst = sc->sc_bst;
diff -r 9c21a4e67f10 -r f04d18965a79 sys/arch/acorn26/iobus/iocvar.h
--- a/sys/arch/acorn26/iobus/iocvar.h   Fri May 11 14:51:39 2012 +0000
+++ b/sys/arch/acorn26/iobus/iocvar.h   Fri May 11 15:39:17 2012 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: iocvar.h,v 1.6 2009/01/18 20:31:08 bjh21 Exp $ */
+/* $NetBSD: iocvar.h,v 1.7 2012/05/11 15:39:17 skrll Exp $ */
 /*-
  * Copyright (c) 1998, 1999 Ben Harris
  * All rights reserved.
@@ -61,7 +61,7 @@
        struct evcnt            sc_sclkev;
        struct timecounter      sc_tc;
        u_int                   sc_tcbase;
-       u_int8_t                sc_ctl;
+       uint8_t                 sc_ctl;
 };
 
 extern device_t the_ioc;
@@ -71,10 +71,10 @@
 extern int ioc_irq_status(int);



Home | Main Index | Thread Index | Old Index
diff -r 9c21a4e67f10 -r f04d18965a79 sys/arch/acorn26/acorn26/machdep.c
--- a/sys/arch/acorn26/acorn26/machdep.c        Fri May 11 14:51:39 2012 +0000
+++ b/sys/arch/acorn26/acorn26/machdep.c        Fri May 11 15:39:17 2012 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: machdep.c,v 1.35 2011/06/15 15:03:51 tsutsui Exp $ */
+/* $NetBSD: machdep.c,v 1.36 2012/05/11 15:39:17 skrll Exp $ */
 
 /*-
  * Copyright (c) 1998 Ben Harris
@@ -32,7 +32,7 @@
 
 #include <sys/param.h>
 
-__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.35 2011/06/15 15:03:51 tsutsui Exp $");
+__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.36 2012/05/11 15:39:17 skrll Exp $");
 
 #include <sys/buf.h>
 #include <sys/kernel.h>
@@ -124,9 +124,9 @@
                 * anyone can tell me how to fake a control-reset in
                 * software, I'd be most grateful.
                 */
-               *(volatile u_int8_t *)0x9c2 = 2; /* Zero page magic */
-               *(volatile u_int32_t *)0
-                       = *(volatile u_int32_t *)MEMC_ROM_LOW_BASE;
+               *(volatile uint8_t *)0x9c2 = 2; /* Zero page magic */
+               *(volatile uint32_t *)0
+                       = *(volatile uint32_t *)MEMC_ROM_LOW_BASE;
                /* reboot in SVC mode, IRQs and FIQs disabled */
                __asm volatile("movs pc, %0" : :
                    "r" (R15_MODE_SVC | R15_FIQ_DISABLE | R15_IRQ_DISABLE));